==> jasmine-dom-0.0.1.tgz: package/README.md <==
node-jasmine-dom
================

Run your browser-based [jasmine][1] specs headless with [node.js][2]. Then 
output in one of many formats such as JSON or JUnit XML (perfect
for integration with CI servers like [Jenkins][3]).

usage
-----
Construct your SpecRunner.html as shown in the jasmine examples,
then run:

    bin/jasmine-dom --runner path/to/SpecRunner.html

You can optionally provide the following arguments:

 * <code>--help</code>, provides usage information
 * <code>--format simple|nice|json|html|junit</code>, displays the result in the specified format
 * <code>--output path</code>, writes the output to the specified file

example 1
---------
    bin/jasmine-dom --runner examples/runner.html --format nice

will output:

    Failed: 
     - In Example functions, Should fail!!: Expected 3 to equal 8.

example 2
---------

    bin/jasmine-dom --runner examples/runner.html --format junit --output javascript_results.xml

will write to javascript_results.xml:

    <testsuite>
        <testcase classname="/Users/andrew/development/node-jasmine-dom/examples/runner.html.Example_functions_that_update_the_DOM.Should_add_two_numbers" name="expect toEqual 7" time="undefined"/>
        <testcase classname="/Users/andrew/development/node-jasmine-dom/examples/runner.html.Example_functions.Should_multiply_two_numbers" name="expect toEqual 40" time="undefined"/>
        <testcase classname="/Users/andrew/development/node-jasmine-dom/examples/runner.html.Example_functions.Should_fail!!" name="expect toEqual 8">
            <failure>
                <![CDATA[
                    FAILURE in spec "Should fail!!": Expected 3 to equal 8.
                    Error: Expected 3 to equal 8.
                        at new <anonymous> (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:94:50)
                        at [object Object].toEqual (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:1138:29)
                        at [object Object].<anonymous> (/Users/andrew/development/node-jasmine-dom/examples/tests/spec/example-functions_spec.js:10:13)
                        at [object Object].execute (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:968:15)
                        at [object Object].next_ (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:1739:31)
                        at [object Object].start (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:1692:8)
                        at [object Object].execute (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:2018:14)
                        at [object Object].next_ (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:1739:31)
                        at [object Object].start (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:1692:8)
                        at [object Object].execute (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:2163:14)
                ]]>
            </failure>
        </testcase>
    </testsuite>

have you seen **[jasmine-node][4]**?
------------------------------------
It's provided a lot of inspiration for this project, and may be just what
you're looking for. If you're not reliant on a DOM, then it's worth checking
out.

[1]: http://pivotal.github.com/jasmine/
[2]: http://nodejs.org/
[3]: http://jenkins-ci.org/
[4]: https://github.com/mhevery/jasmine-node

==> jasmine-dom-0.1.0.tgz: package/README.md <==
node-jasmine-dom
================

Run your browser-based [jasmine][1] specs headless with [node.js][2]. Then 
output in one of many formats such as JSON or JUnit XML (perfect
for integration with CI servers like [Jenkins][3]).

installation
------------
1. you've got [npm][4], right?
2. Groovy. <code>npm install jasmine-dom</code>, and you're away laughing.

usage
-----
Construct your SpecRunner.html as shown in the jasmine examples,
then run:

    jasmine-dom --runner path/to/SpecRunner.html

You can optionally provide the following arguments:

 * <code>--help</code>, provides usage information
 * <code>--format simple|nice|json|html|junit</code>, displays the result in the specified format
 * <code>--output path</code>, writes the output to the specified file
 * <code>--server [port]</code>, serves a simple (but effective) page showing the current state
                                 of the tests. You can also specify an optional <code>--refresh
                                 intervalInMS</code> argument to specify the wait between running
                                 the tests (because the server is constantly running 'em).

server
------

    jasmine-dom --runner examples/runner.html --server 8090 --refresh 3000

will run a server on http://localhost:8090/. Here a simple green or red page will reflect the current state
of your tests. The tests will run every 3000ms, and the page ajaximatically updated with the result.

If you'd like to see the default jasmine html, visit http://localhost:8090/jasmine. Note, the result is still
obtained via the nodejs runner (i.e. it wasn't run in your browser).

example 1
---------
    jasmine-dom --runner examples/runner.html --format nice

will output:

    Failed: 
     - In Example functions, Should fail!!: Expected 3 to equal 8.

example 2
---------

    jasmine-dom --runner examples/runner.html --format junit --output javascript_results.xml

will write to javascript_results.xml:

    <testsuite>
        <testcase classname="/Users/andrew/development/node-jasmine-dom/examples/runner.html.Example_functions_that_update_the_DOM.Should_add_two_numbers" name="expect toEqual 7" time="undefined"/>
        <testcase classname="/Users/andrew/development/node-jasmine-dom/examples/runner.html.Example_functions.Should_multiply_two_numbers" name="expect toEqual 40" time="undefined"/>
        <testcase classname="/Users/andrew/development/node-jasmine-dom/examples/runner.html.Example_functions.Should_fail!!" name="expect toEqual 8">
            <failure>
                <![CDATA[
                    FAILURE in spec "Should fail!!": Expected 3 to equal 8.
                    Error: Expected 3 to equal 8.
                        at new <anonymous> (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:94:50)
                        at [object Object].toEqual (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:1138:29)
                        at [object Object].<anonymous> (/Users/andrew/development/node-jasmine-dom/examples/tests/spec/example-functions_spec.js:10:13)
                        at [object Object].execute (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:968:15)
                        at [object Object].next_ (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:1739:31)
                        at [object Object].start (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:1692:8)
                        at [object Object].execute (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:2018:14)
                        at [object Object].next_ (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:1739:31)
                        at [object Object].start (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:1692:8)
                        at [object Object].execute (/Users/andrew/development/node-jasmine-dom/examples/tests/lib/jasmine.js:2163:14)
                ]]>
            </failure>
        </testcase>
    </testsuite>

have you seen **[jasmine-node][5]**?
------------------------------------
It's provided a lot of inspiration for this project, and may be just what
you're looking for. If you're not reliant on a DOM, then it's worth checking
out.

[1]: http://pivotal.github.com/jasmine/
[2]: http://nodejs.org/
[3]: http://jenkins-ci.org/
[4]: http://npmjs.org/
[5]: https://github.com/mhevery/jasmine-node
